"""CTT Studio - Temporal resonance recording and analysis"""

import numpy as np
import sounddevice as sd
import soundfile as sf
from scipy import signal
from datetime import datetime
import os
import json

__version__ = "0.1.0"

class CTTStudio:
    """CTT Studio main class"""
    def __init__(self, sample_rate=44100):
        self.sr = sample_rate
        self.fft_size = 2048
        self.hop_size = self.fft_size // 4
        self.window = signal.windows.hann(self.fft_size)
        print(f"🎧 CTT Studio v{__version__} initialized")



"""FFT analysis for temporal resonance"""

import numpy as np
from scipy import signal
from ..utils.constants import PHI, ALPHA_RH

class FFTProcessor:
    def __init__(self, fft_size=2048):
        self.fft_size = fft_size
        self.window = signal.windows.hann(fft_size)
        print(f"📊 FFT processor initialized with {fft_size} points")



"""CTT Studio - Temporal resonance recording and analysis"""

from .studio import CTTStudio
from .audio import recorder
from .analysis import fft_processor
from .utils import constants

__version__ = "0.1.0"
__author__ = "Américo Simões"
__email__ = "amexsimoes@gmail.com"

PHI = (1 + 5**0.5) / 2
ALPHA = 0.0302011
ALPHA_RH = 0.0765872



"""Audio recording module with temporal resonance detection"""

import numpy as np
import sounddevice as sd
from ..utils.constants import PHI, ALPHA

class TemporalRecorder:
    def __init__(self, sample_rate=44100):
        self.sr = sample_rate
        print("🎤 Temporal recorder initialized")



from setuptools import setup, find_packages

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setup(
    name="ctt-studio",
    version="0.1.0",
    author="Américo Simões",
    author_email="amexsimoes@gmail.com",
    description="CTT Studio - Temporal resonance recording and analysis",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/SimoesCTT/ctt-studio",
    packages=find_packages(),
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Intended Audience :: Science/Research",
        "License :: OSI Approved :: GNU General Public License v3 (GPLv3)",
        "Operating System :: OS Independent",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Topic :: Scientific/Engineering :: Physics",
        "Topic :: Multimedia :: Sound/Audio :: Analysis",
    ],
    python_requires=">=3.8",
    install_requires=[
        "numpy>=1.21.0",
        "scipy>=1.7.0",
        "sounddevice>=0.4.0",
        "soundfile>=0.10.0",
        "pydub>=0.25.0",
        "matplotlib>=3.0",
    ],
    extras_require={
        "dev": ["pytest>=6.0", "pytest-cov>=2.0"],
        "examples": ["matplotlib>=3.0"],
    },
    scripts=["scripts/ctt-record"],
    include_package_data=True,
)
